@@ -15,8 +15,8 @@
 void progress (unsigned long blocks, unsigned long current);
 
 long long raidseek (unsigned int fd, unsigned long blk);
-extern void print_sb (mdp_super_t *sb);
-int analyze_sb (mdu_version_t * ver, enum mkraidFunc func, 
+extern void print_sb (md_superblock_t *sb);
+int analyze_sb (struct md_version * ver, enum mkraidFunc func, 
 	md_cfg_entry_t * cfg, int forceSanity,
 	int upgradeArray, int forceResync);
 extern int init_set (md_cfg_entry_t * p);
